@@ -2,6 +2,7 @@ context("Test saenet")
 
 
 test_that("saenet works", {
+library(mice)
 mids <- mice(miselect.df, m = 5, printFlag = FALSE)
 dfs <- lapply(1:5, function(i) complete(mids, action = i))
 
@@ -13,9 +14,8 @@ for (i in 1:5) {
 }
 
 weights  <- 1 - rowMeans(is.na(miselect.df))
-pf       <- rep(1, 20)
-adWeight <- rep(1, 20)
-
+pf       <- c(0, rep(1, 19))
+adWeight <- c(0, rep(1, 19))
 
 expect_silent({
     fit <- saenet(x, y, pf, adWeight, weights, family = "binomial", nlambda = 50)})
@@ -23,6 +23,7 @@ expect_silent({
 
 
 test_that("cv.saenet works", {
+library(mice)
 mids <- mice(miselect.df, m = 5, printFlag = FALSE)
 dfs <- lapply(1:5, function(i) complete(mids, action = i))
 
